@@ -1,16 +1,18 @@
 import shlex
 import subprocess
-from typing import Iterable, Optional
+from typing import Iterable
 
 from .config import load_constraints_config
 from .domains import build_domains_from_config
 from .logging_utils import append_log
 
+
 def _load_unbound_domain():
     cfg = load_constraints_config()
     domains = build_domains_from_config(cfg)
     return domains.get("UNBOUND")
 
+
 def confirm_required(cmd: str, patterns: Iterable[str]) -> bool:
     text = cmd.strip()
     for pat in patterns:
@@ -18,6 +20,7 @@ def confirm_required(cmd: str, patterns: Iterable[str]) -> bool:
             return True
     return False
 
+
 def run_unbound_shell(command: str, auto_confirm: bool = False) -> int:
     """Run a shell command in UNBOUND domain.
 
@@ -38,5 +41,4 @@ def run_unbound_shell(command: str, auto_confirm: bool = False) -> int:
     log_path = domain.log_path or "~/.architectos/unbound/logs/unbound.log"
     append_log(log_path, f"UNBOUND RUN: {command}")
 
-    # Skeleton implementation: do not capture output here, just stream it.
     return subprocess.call(command, shell=True)
